@@ -19,10 +19,16 @@ extensions = ['sphinx.ext.napoleon']
 templates_path = ['_templates']
 exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
 
-
-
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
 html_theme = 'sphinx_book_theme'
-html_static_path = ['_static']
\ No newline at end of file
+html_static_path = ['_static']
+html_sidebars = {
+    "**": ["sbt-sidebar-nav.html"]
+}
+html_theme_options = {
+    "repository_url": "https://github.com/CSML-IIT-UCL/kooplearn",
+    "use_repository_button": True,
+    "home_page_in_toc": True,
+}
\ No newline at end of file
